@@ -94,7 +94,7 @@ class GoDirectDevice(ABC):
 	def _read(self, timeout):
 		pass
 
-	def open(self):
+	def open(self, auto_start = False):
 		""" Connect this device and read status/info data to populate the properties
 		in this class.
 		"""
@@ -108,6 +108,8 @@ class GoDirectDevice(ABC):
 			return False
 		if not self._GDX_get_device_info():
 			return False
+		if auto_start:
+			self.start()
 		return True
 
 	def enable_default_sensors(self):
@@ -387,38 +389,49 @@ class GoDirectDevice(ABC):
 	def _GDX_handle_measurement(self, response):
 		self._GDX_dump("MEASUREMENT: ", response)
 
+		value_count = 0
+		sensors = []
+		format_str = "<f"
+		index = 0
+
 		measurement_type = response[4]
 		if measurement_type == self.MEASUREMENT_TYPE_NORMAL_REAL32:
 			self._GDX_dump("REAL32: ", response[9:])
 			sensor_mask = struct.unpack("<H",response[5:7])[0]
+			value_count = struct.unpack("<b",response[7:8])[0]
 			sensors = self._get_sensors_with_mask(sensor_mask)
-			start = 9
-			for i in sensors:
-				measurement = struct.unpack("<f",response[start:start+4])[0]
-				sensors[i].values.append(measurement)
-				start += 4
+			index = 9
 		elif measurement_type == self.MEASUREMENT_TYPE_WIDE_REAL32:
-			self._GDX_dump("WIDE REAL32: ", response[9:])
-			sensor_mask = struct.unpack("<H",response[5:7])[0]
+			self._GDX_dump("WIDE REAL32: ", response[11:])
+			sensor_mask = struct.unpack("<HH",response[5:9])[0]
+			value_count = struct.unpack("<b",response[9:10])[0]
 			sensors = self._get_sensors_with_mask(sensor_mask)
-			start = 11
-			for i in sensors:
-				measurement = struct.unpack("<f",response[start:start+4])[0]
-				sensors[i].values.append(measurement)
-				start += 4
+			index = 11
 		elif measurement_type == self.MEASUREMENT_TYPE_SINGLE_CHANNEL_REAL32 or measurement_type == self.MEASUREMENT_TYPE_APERIODIC_REAL32:
 			self._GDX_dump("SINGLE REAL32: ", response[8:])
-			sensor = struct.unpack("<H",response[6:8])[0]
-			measurement = struct.unpack("<f",response[8:13])[0]
-			sensors[sensor].values.append(measurement)
+			sensor_number = struct.unpack("<b",response[6:7])[0]
+			value_count = struct.unpack("<b",response[7:8])[0]
+			index = 8
+			sensors[0] = self._sensors[sensor_number]
 		elif measurement_type == self.MEASUREMENT_TYPE_SINGLE_CHANNEL_INT32 or measurement_type == self.MEASUREMENT_TYPE_APERIODIC_INT32:
 			self._GDX_dump("SINGLE INT32: ", response[8:])
-			sensor = struct.unpack("<H",response[6:8])[0]
-			measurement = struct.unpack("<i",response[8:])[0]
-			sensors[sensor].values.append(measurement)
+			sensor_number = struct.unpack("<b",response[6:7])[0]
+			value_count = struct.unpack("<b",response[7:8])[0]
+			index = 8
+			format_str = "<i"
+			sensors[0] = self._sensors[sensor_number]
 		else:
 			self._logger.info("Unknown measurement type")
 			return False
+
+		count = 0 
+		while count < value_count:
+			for i in sensors:
+				measurement = struct.unpack(format_str,response[index:index+4])[0]
+				sensors[i].values.append(measurement)
+				index += 4
+			count += 1
+
 		return True
 
 	############################################################################
@@ -760,6 +773,8 @@ class GoDirectDevice(ABC):
 
 	@property
 	def charger_state(self):
+		""" int:  0 = Idle, 1 = Charging, 2 = Complete, 3 = Error
+		"""
 		return self._charger_state
 
 	@property
